@@ -14,12 +14,15 @@ class Config:
         self._cli_templates = self.load_templates(templates)
         self._config_templates = self._config.get('template_defaults', {})
 
+    def __str__(self):
+        return json.dumps(self._config, indent=2)
+
     def load_templates(self, templates):
         t = {}
         if templates is None:
             return t
         for x in templates:
-            vals = x.split('=')
+            vals = x.split('=', 1)
             t[vals[0]] = vals[1]
         return t
 
@@ -43,10 +46,11 @@ class Config:
         flag_vals = []
         flags = self.get('curl_flags', {})
 
+        print(flags)
         for flag in flags:
             flag_vals.append("{flag} {value}".format(flag=flag, value=flags[flag]))
 
-        return self._format_config(' '.join(flags), 'curl_flags')
+        return self._format_config(' '.join(flag_vals), 'curl_flags')
 
     def _format_config(self, value, key):
         merged_template = {**self._config_templates, **self._cli_templates}
@@ -73,7 +77,7 @@ def pars_args():
 
 def merge_config(parent, child):
     '''
-    Merges two configs together. Values set in the child take prescendece over
+    Merges two configs together. Values set in the child take precendece over
     values in the parent.
     '''
 
@@ -150,7 +154,7 @@ def main():
         print('Curl Command:')
         print(cmd)
         print('Parsed Config:')
-        print(json.dumps(config, indent=2))
+        print(config)
 
     stream = os.popen(cmd)
     for line in stream.readlines():
